source("hypothesis_test_omnibus.R")

n_dims <- 3
D <- 1.7
n_conditions <- length(simulated_data_cat)

##############################################################################
# omnibus test
##############################################################################
library(abind)
library(progress)

# test whether each person has a significant change
omnibus_test_cat <- list()

for (n in 1:n_conditions) {
  omnibus_test_cat[[n]] <- simulated_data_cat[[n]][1:4] # copy the setup of the condition
  resp <- simulated_data_cat[[n]]$resp
  n_occasions <- simulated_data_cat[[n]]$n_occasions
  theta_pooled <- simulated_data_cat[[n]]$theta_pooled
  theta_occasion <- simulated_data_cat[[n]]$theta_occasion
  items_used <- simulated_data_cat[[n]]$items_used
  test_results <- array(NA, c(n_people, 4), list(c(), c("LRT", "MWT", "MMWT", "ST")))
  pb <- progress_bar$new(total = n_people)
  
  # perform each omnibus test for each person
  for (j in 1:n_people) {
    stacked_item_params <- array(NA, c(max_len, n_dims + n_cats - 1, n_occasions))
    for (t in 1:n_occasions)
      stacked_item_params[, , t] <- item_params_cat[items_used[j, , t], ]
    
    test_results[j, "LRT"] <- LRT_omnibus(stacked_item_params, resp[j, , ], theta_pooled[j, ], t(theta_occasion[j, , ]), n_dims, n_occasions, D)$decision
    test_results[j, "MWT"] <- MWT_omnibus(stacked_item_params, resp[j, , ], theta_pooled[j, ], t(theta_occasion[j, , ]), n_dims, n_occasions, D)$decision
    if (n_occasions > 2)
      test_results[j, "MMWT"] <- MMWT_omnibus(stacked_item_params, resp[j, , ], theta_pooled[j, ], t(theta_occasion[j, , ]), n_dims, n_occasions, D)$decision
    test_results[j, "ST"] <- ST_omnibus(stacked_item_params, resp[j, , ], theta_pooled[j, ], n_dims, n_occasions, D)$decision
    pb$tick()
  }
  
  print(paste("Condition", n, "completed!"))
  omnibus_test_cat[[n]]$test_results <- test_results
}

# compute the proportion of significant change for each condition
omnibus_test_cat_agg <- data.frame(matrix(nrow = n_conditions, ncol = 8))
colnames(omnibus_test_cat_agg) <- c("n_occasions", "corr", "change", "pattern", "LRT", "MWT", "MMWT", "ST")

for (n in 1:n_conditions) {
  omnibus_test_cat_agg[n, "n_occasions"] <- omnibus_test_cat[[n]]$n_occasions
  omnibus_test_cat_agg[n, "corr"] <- omnibus_test_cat[[n]]$corr
  omnibus_test_cat_agg[n, "change"] <- paste(omnibus_test_cat[[n]]$change, collapse = ", ")
  omnibus_test_cat_agg[n, "pattern"] <- omnibus_test_cat[[n]]$pattern
  omnibus_test_cat_agg[n, c("LRT", "MWT", "MMWT", "ST")] <- round(colMeans(omnibus_test_cat[[n]]$test_results), 3)
}

omnibus_test_cat_agg
