# Multivaraite hypothesis testing for intra-individual change -- multiple occasions
# Graded Response model in computerized adaptive tests

source("sim_items.R")
source("sim_people.R")
source("estimate_theta.R")
source("cat.R")
library(progress)

sim <- function(item_params, n_people, n_dims, max_len, n_cats, n_occasions, corr, change, pattern, seed_num) {
  set.seed(seed_num)
  true_theta <- sim_people(n_people, n_dims, n_occasions, corr, change, pattern)
  pb <- progress_bar$new(total = n_people)
  
  resp <- array(0, c(n_people, max_len, n_occasions))
  items_used <- array(0, c(n_people, max_len, n_occasions))
  theta_pooled <- array(NA, c(n_people, n_dims))
  theta_occasion <- array(NA, c(n_people, n_dims, n_occasions))
  
  for (j in 1:n_people) {
    stacked_item_params <- array(NA, c(max_len * n_occasions, n_dims + n_cats - 1))
    
    for (t in 1:n_occasions) {
      if (t == 1) initial_theta <- rep(0, n_dims)
      else initial_theta <- t(theta_occasion[j, , t - 1])
      cat_output <- cat_sim(true_theta[j, , t], initial_theta, item_params, n_dims, rep(n_cats, n_items), D, max_len, c(5, 5, 5), c(100, 100, 100))
      resp[j, , t] <- cat_output[, "resp"]
      items_used[j, , t] <- cat_output[, "items_used"]
      stacked_item_params[(max_len * (t - 1) + 1):(max_len * t), ] <- item_params_cat[cat_output[, "items_used"], ]
      theta_occasion[j, , t] <- cat_output[max_len, c("theta_hat1", "theta_hat2", "theta_hat3")]
    }
    theta_pooled[j, ] <- estimate_theta(stacked_item_params, as.vector(resp[j, , ]), n_dims, D)$theta_hat
    pb$tick()
  }
  
  output <- list(
    n_occasions = n_occasions, 
    corr = corr, 
    change = change, 
    pattern = pattern, 
    true_theta = true_theta, 
    theta_pooled = theta_pooled,
    theta_occasion = theta_occasion,
    resp = resp,
    items_used = items_used
  )
  return(output)
}

n_dims <- 3
n_items <- 300
n_cats <- 4 # no. of categories
D <- 1.7
n_people <- 5
max_len <- 45

item_params_cat <- sim_items(n_items, n_dims, n_cats, D, 10)

n_occasions <- c(2, 4)
corr <- c(0.2, 0.5, 0.7)
change <- list(c(0.0, 0.0, 0.0), # for false positive rate
               c(0.2, 0.2, 0.2), c(0.30, 0.30, 0), c(0.6, 0, 0), 
               c(0.3, 0.3, 0.3), c(0.45, 0.45, 0), c(0.9, 0, 0))
pattern <- c("linear", "non-linear")
simulated_data_cat <- list()

n <- 1
for (t in n_occasions) {
  for (r in corr) {
    for (d in change) {
      for (p in pattern) {
        if (p == "non-linear" & (t == 2 | all(d == c(0.0, 0.0, 0.0)))) next
        simulated_data_cat[[n]] <- sim(item_params_cat, n_people, n_dims, max_len, n_cats, n_occasions = t, corr = r, change = d, pattern = p, seed_num = 100 + n)
        print(paste("Condition", n, "completed!"))
        n <- n + 1
      }
    }
  }
}
