source("hypothesis_test_omnibus.R")

n_dims <- 3
D <- 1.7
n_conditions <- length(simulated_data)

##############################################################################
# omnibus test
##############################################################################
library(abind)
library(progress)

# test whether each person has a significant change
omnibus_test <- list()

for (n in 1:n_conditions) {
  omnibus_test[[n]] <- simulated_data[[n]][1:4] # copy the setup of the condition
  resp <- simulated_data[[n]]$resp
  n_occasions <- simulated_data[[n]]$n_occasions
  theta_pooled <- simulated_data[[n]]$theta_pooled
  theta_occasion <- simulated_data[[n]]$theta_occasion
  repeated_item_params <- abind(replicate(n_occasions, item_params, simplify = FALSE), along = 3)
  test_results <- array(NA, c(n_people, 4), list(c(), c("LRT", "MWT", "MMWT", "ST")))
  pb <- progress_bar$new(total = n_people)
  
  # perform each omnibus test for each person
  for (j in 1:n_people) {
    test_results[j, "LRT"] <- LRT_omnibus(repeated_item_params, resp[j, , ], theta_pooled[j, ], t(theta_occasion[j, , ]), n_dims, n_occasions, D)$decision
    test_results[j, "MWT"] <- MWT_omnibus(repeated_item_params, resp[j, , ], theta_pooled[j, ], t(theta_occasion[j, , ]), n_dims, n_occasions, D)$decision
    if (n_occasions > 2)
      test_results[j, "MMWT"] <- MMWT_omnibus(repeated_item_params, resp[j, , ], theta_pooled[j, ], t(theta_occasion[j, , ]), n_dims, n_occasions, D)$decision
    test_results[j, "ST"] <- ST_omnibus(repeated_item_params, resp[j, , ], theta_pooled[j, ], n_dims, n_occasions, D)$decision
    pb$tick()
  }
  
  print(paste("Condition", n, "completed!"))
  omnibus_test[[n]]$test_results <- test_results
}

# compute the proportion of significant change for each condition
omnibus_test_agg <- data.frame(matrix(nrow = n_conditions, ncol = 8))
colnames(omnibus_test_agg) <- c("n_occasions", "corr", "change", "pattern", "LRT", "MWT", "MMWT", "ST")

for (n in 1:n_conditions) {
  omnibus_test_agg[n, "n_occasions"] <- omnibus_test[[n]]$n_occasions
  omnibus_test_agg[n, "corr"] <- omnibus_test[[n]]$corr
  omnibus_test_agg[n, "change"] <- paste(format(omnibus_test[[n]]$change, 1), collapse = ", ")
  omnibus_test_agg[n, "pattern"] <- omnibus_test[[n]]$pattern
  omnibus_test_agg[n, c("LRT", "MWT", "MMWT", "ST")] <- round(colMeans(omnibus_test[[n]]$test_results), 3)
}

omnibus_test_agg
