# Multivaraite hypothesis testing for intra-individual change -- multiple occasions
# Graded Response model in conventional tests

source("sim_items.R")
source("sim_people.R")
source("estimate_theta.R")
library(abind)

stack <- function(three_dim_array) {
  for (i in 1:dim(three_dim_array)[3]) {
    if (i == 1) result <- three_dim_array[, , 1]
    else result <- rbind(result, three_dim_array[, , i])
  }
  return(result)
}

sim <- function(item_params, n_people, n_dims, n_occasions, corr, change, pattern, seed_num) {
  set.seed(seed_num)
  
  # simulate theta
  true_theta <- sim_people(n_people, n_dims, n_occasions, corr, change, pattern)
  
  # simulate responses
  a <- item_params[, 1:n_dims, drop = F]
  b <- item_params[, (n_dims + 1):ncol(item_params), drop = F]
  
  resp <- array(0, c(n_people, n_items, n_occasions))
  for (t in 1:n_occasions) {
    for (j in 1:n_people) {
      rand <- runif(n_items)
      cum_P <- sapply(1:(n_cats - 1), function(h) 1 / (1 + exp(-D * rowSums(a * t(outer(true_theta[j, , t], b[, h], "-"))))))
      resp[j, , t] <- colSums(sapply(1:n_items, function(x) cum_P[x, ] > rand[x]))
    }
  }
  
  # estimate thetas
  theta_pooled <- array(NA, c(n_people, n_dims))
  theta_occasion <- array(NA, c(n_people, n_dims, n_occasions))
  repeated_item_params <- abind(replicate(n_occasions, item_params, simplify = FALSE), along = 3)
  
  for (j in 1:n_people) {
    theta_pooled[j, ] <- estimate_theta(stack(repeated_item_params), as.vector(resp[j, , ]), n_dims, D)$theta_hat
    for (t in 1:n_occasions)
      theta_occasion[j, , t] <- estimate_theta(item_params, resp[j, , t], n_dims, D)$theta_hat
  }
  
  output <- list(
    n_occasions = n_occasions, 
    corr = corr, 
    change = change, 
    pattern = pattern, 
    true_theta = true_theta, 
    theta_pooled = theta_pooled,
    theta_occasion = theta_occasion,
    resp = resp
  )
  return(output)
}

n_dims <- 3
n_items <- 45
n_cats <- 4 # no. of categories
D <- 1.7
n_people <- 10000

item_params <- sim_items(n_items, n_dims, n_cats, D, 16)

n_occasions <- c(2, 4)
corr <- c(0.2, 0.5, 0.7)
change <- list(c(0.0, 0.0, 0.0), # for false positive rate
               c(0.2, 0.2, 0.2), c(0.30, 0.30, 0), c(0.6, 0, 0), 
               c(0.3, 0.3, 0.3), c(0.45, 0.45, 0), c(0.9, 0, 0))
pattern <- c("linear", "non-linear")
simulated_data <- list()

n <- 1
for (t in n_occasions) {
  for (r in corr) {
    for (d in change) {
      for (p in pattern) {
        if (p == "non-linear" & (t == 2 | all(d == c(0.0, 0.0, 0.0)))) next
        simulated_data[[n]] <- sim(item_params, n_people, n_dims, n_occasions = t, corr = r, change = d, pattern = p, seed_num = 100 + n)
        print(paste("Condition", n, "completed!"))
        n <- n + 1
      }
    }
  }
}
