sim_items <- function(n_items, n_dims, n_cats, D, seed_num) {
  
  ############################################################################## 
  # simulate item parameters for multivariate graded response model
  ##############################################################################
  # Parameters
  # n_items: no. of items
  # n_dims: no. of dimensions
  # n_cats: no. of categories
  # D: scaling constant, 1 for logistic model, 1.7 for normal ogive model
  # seed_num: seed no. (for reproducibility)
  #
  # Returns
  # a matrix of item parameters
  ##############################################################################
  set.seed(seed_num)
  items_per_dim <- n_items / n_dims

  a <- array(0, c(n_items, n_dims))
  for (k in 1:n_dims) {
    i <- (items_per_dim * (k - 1) + 1):(items_per_dim * k)
    a[i, k] <- runif(items_per_dim, 1.1, 2.8)
  }
  
  b <- array(0, c(n_items, n_cats - 1))
  b[, 1] <- runif(n_items, -3, -1)
  b[, 2] <- runif(n_items, -1, 1)
  b[, 3] <- runif(n_items, 1, 3)
  
  item_params <- cbind(a, b)
  colnames(item_params) <- c(paste0("a", 1:n_dims), paste0("b", 1:n_dims))
  return(item_params)
}