sim_people <- function(n_people, n_dims, n_occasions, corr, change, pattern) {
  
  ##############################################################################
  # simulate person parameters from a multivariate normal
  ##############################################################################
  # Parameters
  # n_people: no. of people
  # n_dims: no. of latent trait dimensions
  # n_occasions: no. of occasions
  # corr: correlation between latent trait dimensions
  # change: amount of change in thetas across occasions
  # pattern: pattern of change, either "linear" or "non-linear"
  #          ignored if n_occasion <= 2
  #
  # Returns
  # a 3-dimensional array (1: people; 2: latent trait dimensions; 3: occasions)
  ##############################################################################
  
  thetas <- array(0, c(n_people, n_dims, n_occasions))
  
  # for the first time point
  mu <- rep(0, n_dims)
  Sigma <- array(corr, c(n_dims, n_dims))
  diag(Sigma) <- 1
  thetas[, , 1] <- MASS::mvrnorm(n_people, mu, Sigma)
  
  # for the second time point and onwards
  if (n_occasions == 2)
    thetas[, , 2] <- thetas[, , 1] + change
  else if (n_occasions > 2) {
    for (t in 1:(n_occasions - 2))
      thetas[, , t + 1] <- thetas[, , t] + change
    if (pattern == "linear")
      thetas[, , n_occasions] <- thetas[, , n_occasions - 1] + change
    else if (pattern == "non-linear")
      thetas[, , n_occasions] <- thetas[, , n_occasions - 1]
  }
  return(thetas)
}
